@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/jobstat.c,v 1.102 2012/02/16 10:34:25 jfilipov Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/jobstat.c,v 1.102.2.1 2012/07/12 10:39:26 valtri Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -15,7 +15,7 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/jobstat.c,v 1.102 2012/02/16 10:34:25 jfilipov Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/jobstat.c,v 1.102.2.1 2012/07/12 10:39:26 valtri Exp $"
 
 #include <inttypes.h>
 #include <stdio.h>
@@ -200,7 +200,7 @@ int edg_wll_JobStatusServer(
 							edg_wll_SetError(ctx, ENOMEM, "edg_wll_JobStatusServer() calloc children_states failed!");
 							goto rollback;
 						}
-						while ((num_f = edg_wll_FetchRow(ctx, sh, sizeof(out_stat), NULL, out_stat)) == 3
+						while ((num_f = edg_wll_FetchRow(ctx, sh, sizeof(out_stat)/sizeof(out_stat[0]), NULL, out_stat)) == 3
 							&& i < num_sub) {
 							if (!strcmp(INTSTAT_VERSION,out_stat[0])) {
 								js = dec_intJobStat(out_stat[1], &s_out);
