@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/lb_authz.c,v 1.49.2.1 2012/04/30 10:13:20 valtri Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/lb_authz.c,v 1.49.2.4 2012/05/16 13:12:26 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -22,6 +22,7 @@ limitations under the License.
 #include <errno.h>
 
 #include <openssl/x509.h>
+#include <gssapi.h>
 #include "lcas/lcas_pem.h"
 #include "voms/voms_apic.h"
 #include "glite/lb/context-int.h"
@@ -922,7 +923,6 @@ check_store_authz(edg_wll_Context ctx, edg_wll_Event *ev)
    const char *request = NULL;
    int ret;
    authz_action action;
-   struct _edg_wll_GssPrincipal_data princ;
 
    switch (ev->any.type) {
 	case EDG_WLL_EVENT_REGJOB:
@@ -970,9 +970,7 @@ check_store_authz(edg_wll_Context ctx, edg_wll_Event *ev)
    if (policy_file == NULL)
         return 0;
 
-   princ.name = ctx->peerName;
-   princ.fqans = ctx->fqans;
-   ret = check_authz_policy(&ctx->authz_policy, &princ, action);
+   ret = check_authz_policy_ctx(ctx, action);
    if (ret == 1)
       return 0;
 
@@ -1232,9 +1230,6 @@ check_jobstat_authz(edg_wll_Context ctx,
     if (stat->payload_owner && edg_wll_gss_equal_subj(peer->name, stat->payload_owner))
 	return 1;
 
-    if ((!(*authz_flags & READ_ANONYMIZED)) && (check_authz_policy(&ctx->authz_policy, peer, READ_ANONYMIZED)))
-	*authz_flags |= READ_ANONYMIZED;
-
     if (edg_wll_amIroot(peer->name, peer->fqans, &ctx->authz_policy))
 	return 1;
     if (acl && edg_wll_CheckACL_princ(ctx, acl, EDG_WLL_CHANGEACL_READ, peer) == 0)
@@ -1243,9 +1238,12 @@ check_jobstat_authz(edg_wll_Context ctx,
 
     if (check_authz_policy(&ctx->authz_policy, peer, READ_ALL))
 	return 1;
+    if ((!(*authz_flags & READ_ANONYMIZED)) && (check_authz_policy(&ctx->authz_policy, peer, READ_ANONYMIZED))) {
+	*authz_flags |= READ_ANONYMIZED;
+	return 1;
+    }
     if (check_authz_policy(&ctx->authz_policy, peer, STATUS_FOR_MONITORING)) {
 	*authz_flags |= STATUS_FOR_MONITORING;
-	return 1;
     }
 
     return 0;
