@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/srv_purge.c,v 1.53 2012/01/24 14:27:01 valtri Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/srv_purge.c,v 1.53.2.2 2012/06/05 12:54:07 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -248,18 +248,13 @@ int edg_wll_PurgeServer(edg_wll_Context ctx,const edg_wll_PurgeRequest *request,
 	struct timeval	tp;
 	edg_wll_JobStat	stat;
 	purge_ctx_t prg;
-	struct _edg_wll_GssPrincipal_data princ;
 
 	memset(&prg, 0, sizeof prg);
 	prg.naffected_jobs = 0;
 	prg.parse = 0;
 	prg.dumpfile = -1;
 
-	memset(&princ, 0, sizeof princ);
-	princ.name = ctx->peerName;
-        princ.fqans = ctx->fqans;
-
-	if (!ctx->noAuth && !check_authz_policy(&ctx->authz_policy, &princ, PURGE)) {
+	if (!ctx->noAuth && !check_authz_policy_ctx(ctx, PURGE)) {
 		edg_wll_SetError(ctx,EPERM,"only superusers may purge");
 		goto abort;
 	}
@@ -562,6 +557,7 @@ static int get_jobid_suffix(edg_wll_Context ctx, glite_jobid_const_t job, enum e
         	case EDG_WLL_STAT__PARTITIONABLE_UNUSED:
 	        case EDG_WLL_STAT__PARTITIONED_UNUSED:
         	case EDG_WLL_STAT_COLLECTION:
+		case EDG_WLL_STAT_CREAM:
                 case EDG_WLL_STAT_FILE_TRANSFER:
                 case EDG_WLL_STAT_FILE_TRANSFER_COLLECTION:
 			// glite jobs, no suffix
@@ -611,6 +607,7 @@ static int get_jobid_prefix(edg_wll_Context ctx, glite_jobid_const_t job, enum e
         	case EDG_WLL_STAT__PARTITIONABLE_UNUSED:
 	        case EDG_WLL_STAT__PARTITIONED_UNUSED:
         	case EDG_WLL_STAT_COLLECTION:
+		case EDG_WLL_STAT_CREAM:
 		case EDG_WLL_STAT_FILE_TRANSFER:
 		case EDG_WLL_STAT_FILE_TRANSFER_COLLECTION:
 			// glite job prefix
