@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/stats.c,v 1.18 2011/10/25 13:32:14 zsustr Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/stats.c,v 1.18.2.1 2012/05/16 13:12:26 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -547,15 +547,11 @@ static int findStat(
 )
 {
 	edg_wll_JobStatCode later_state;
-	struct _edg_wll_GssPrincipal_data princ;
 
 	edg_wll_ResetError(ctx);
-	memset(&princ, 0, sizeof princ);
-	princ.name = ctx->peerName;
-	princ.fqans = ctx->fqans;
 	switch (ctx->count_statistics) {
                 case 0: return edg_wll_SetError(ctx,ENOSYS,NULL);
-                case 1: if (!ctx->noAuth && !check_authz_policy(&ctx->authz_policy, &princ, GET_STATISTICS))
+                case 1: if (!ctx->noAuth && !check_authz_policy_ctx(ctx, GET_STATISTICS))
 				return edg_wll_SetError(ctx, EPERM, NULL);
                 case 2: break;
                 default: abort();
